Utilities for set- and bag-of-word-based models.

For example, split text into a collection of tokens (usually words or ngrams),
then count the number of times they appear in each document or
in the collection of documents.

This also is relevant for other sorts of unordered collections.
For example, movies might be tagged with multiple genres such as "fantasy" and "action".

## Sets

::: mismo.sets.jaccard

## Bag-Of-Words

::: mismo.sets.add_array_value_counts
::: mismo.sets.add_tfidf
::: mismo.sets.document_counts
::: mismo.sets.rare_terms
::: mismo.sets.term_idf
